closestmatch-rs
Inspired by closestmatch a golang library. This library fuzzy matches an input string to a list of target strings.
Structs
- Closest
Match - The
ClosestMatchstruct stores informations about the dictionary of known words and the different sizes for the bags of words.